@@ -1,21 +1,14 @@
-# Copyright (c) 2014, cPanel, Inc.
-# All rights reserved.
-# http://cpanel.net/
-#
-# This is free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.  See the LICENSE file for further details.
-
 package Filesys::POSIX::Inode;
 
 use strict;
 use warnings;
 
 use Filesys::POSIX::Bits;
-use Filesys::POSIX::Error qw(throw);
+use Carp qw/confess/;
 
 =head1 NAME
 
-Filesys::POSIX::Inode - Base class for filesystem inode objects
+Filesys::POSIX::Inode
 
 =head1 DESCRIPTION
 
@@ -25,9 +18,9 @@ analyzing its attributes.
 
 =over
 
-=item C<$inode-E<gt>dir>
+=item $inode->dir()
 
-Returns true if the current inode refers to a directory.
+Returns a value indicating whether or not the current inode is a directory.
 
 =cut
 
@@ -35,7 +28,7 @@ sub dir {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFDIR;
 }
 
-=item C<$inode-E<gt>link>
+=item $inode->link()
 
 Returns true if the current inode is a symlink.
 
@@ -45,7 +38,7 @@ sub link {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFLNK;
 }
 
-=item C<$inode-E<gt>file>
+=item $inode->file()
 
 Returns true if the current inode is a regular file.
 
@@ -55,7 +48,7 @@ sub file {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFREG;
 }
 
-=item C<$inode-E<gt>char>
+=item $inode->char()
 
 Returns true if the current inode is a character device.
 
@@ -65,7 +58,7 @@ sub char {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFCHR;
 }
 
-=item C<$inode-E<gt>block>
+=item $inode->block()
 
 Returns true if the current inode is a block device.
 
@@ -75,9 +68,9 @@ sub block {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFBLK;
 }
 
-=item C<$inode-E<gt>fifo>
+=item $inode->fifo()
 
-Returns true if the current inode is a FIFO.
+Returns true if the current inode is a Unix FIFO.
 
 =cut
 
@@ -85,47 +78,7 @@ sub fifo {
     ( shift->{'mode'} & $S_IFMT ) == $S_IFIFO;
 }
 
-=item C<$inode-E<gt>sock>
-
-Returns true if the current inode refers to a socket.
-
-=cut
-
-sub sock {
-    ( shift->{'mode'} & $S_IFMT ) == $S_IFSOCK;
-}
-
-=item C<$inode-E<gt>major>
-
-If the current inode is a block or character device, return the major number.
-Otherwise, an EINVAL is thrown.
-
-=cut
-
-sub major {
-    my ($self) = @_;
-
-    throw &Errno::EINVAL unless $self->char || $self->block;
-
-    return ( $self->{'rdev'} & 0xffff0000 ) >> 16;
-}
-
-=item C<$inode-E<gt>minor>
-
-If the current inode is a block or character device, return the minor number.
-Otherwise, an EINVAL is thrown.
-
-=cut
-
-sub minor {
-    my ($self) = @_;
-
-    throw &Errno::EINVAL unless $self->char || $self->block;
-
-    return $self->{'rdev'} & 0x0000ffff;
-}
-
-=item C<$inode-E<gt>perms>
+=item $inode->perms()
 
 Returns the permissions bitfield value of the current inode's mode attribute.
 
@@ -135,7 +88,7 @@ sub perms {
     shift->{'mode'} & $S_IPERM;
 }
 
-=item C<$inode-E<gt>readable>
+=item $inode->readable()
 
 Returns true if the inode is readable by anyone.
 
@@ -145,7 +98,7 @@ sub readable {
     ( shift->{'mode'} & $S_IR ) != 0;
 }
 
-=item C<$inode-E<gt>writable>
+=item $inode->writable()
 
 Returns true if the inode is writable by anyone.
 
@@ -155,7 +108,7 @@ sub writable {
     ( shift->{'mode'} & $S_IW ) != 0;
 }
 
-=item C<$inode-E<gt>executable>
+=item $inode->executable()
 
 Returns true if the inode is executable by anyone.
 
@@ -165,7 +118,7 @@ sub executable {
     ( shift->{'mode'} & $S_IX ) != 0;
 }
 
-=item C<$inode-E<gt>setuid>
+=item $inode->setuid()
 
 Returns true if the inode has a setuid bit set.
 
@@ -175,7 +128,7 @@ sub setuid {
     ( shift->{'mode'} & $S_ISUID ) != 0;
 }
 
-=item C<$inode-E<gt>setgid>
+=item $inode->setgid()
 
 Returns true if the inode has a setgid bit set.
 
@@ -185,7 +138,7 @@ sub setgid {
     ( shift->{'mode'} & $S_ISGID ) != 0;
 }
 
-=item C<$inode-E<gt>update(@st)>
+=item $inode->update(@st)
 
 Updates the current inode object with a list of values as returned by
 L<stat()|perlfunc/stat>.
@@ -195,38 +148,41 @@ L<stat()|perlfunc/stat>.
 sub update {
     my ( $self, @st ) = @_;
 
-    @{$self}{qw(size atime mtime ctime uid gid mode rdev)} =
-      ( @st[ 7 .. 10 ], @st[ 4 .. 5 ], $st[2], $st[6] );
-
-    return $self;
+    @{$self}{qw/size atime mtime ctime uid gid mode rdev/} = ( @st[ 7 .. 10 ], @st[ 4 .. 5 ], $st[2], $st[6] );
 }
 
-=item C<$inode-E<gt>directory>
+=item $inode->directory()
 
 If the current inode is a directory, return the directory object held by it.
-Otherwise, an ENOTDIR is thrown.
+Otherwise, the following exception is issued:
+
+=over
+
+=item Not a directory
+
+=back
 
 =cut
 
 sub directory {
     my ($self) = @_;
-
-    throw &Errno::ENOTDIR unless $self->dir;
+    confess('Not a directory') unless $self->dir;
 
     return $self->{'directory'};
 }
 
-=item C<$inode-E<gt>empty>
+=item $inode->empty()
 
-Uses the above C<$inode-E<gt>directory()> call to obtain the directory for the
-current inode, and returns the result of C<$directory-E<gt>empty()>.
+Uses the above $inode->directory() call to obtain the directory for the current
+inode, and returns true if the directory only contains the '..' and '.' members.
 
 =cut
 
 sub empty {
     my ($self) = @_;
+    my $directory = $self->directory;
 
-    return $self->directory->empty;
+    return $directory->count == 2;
 }
 
 =back
@@ -234,24 +190,3 @@ sub empty {
 =cut
 
 1;
-
-__END__
-
-=head1 AUTHOR
-
-Written by Xan Tronix <xan@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item Rikus Goodell <rikus.goodell@cpanel.net>
-
-=item Brian Carlson <brian.carlson@cpanel.net>
-
-=back
-
-=head1 COPYRIGHT
-
-Copyright (c) 2014, cPanel, Inc.  Distributed under the terms of the Perl
-Artistic license.
