@@ -1,40 +1,15 @@
-# Copyright (c) 2014, cPanel, Inc.
-# All rights reserved.
-# http://cpanel.net/
-#
-# This is free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.  See the LICENSE file for further details.
-
 package Filesys::POSIX::Mem::Bucket;
 
 use strict;
 use warnings;
 
 use Filesys::POSIX::Bits;
-use Filesys::POSIX::Bits::System;
 use Filesys::POSIX::IO::Handle ();
-use Filesys::POSIX::Error qw(throw);
 
-use Fcntl;
-use Carp       ();
-use File::Temp ();
+use File::Temp qw/mkstemp/;
+use Carp qw/confess/;
 
-=head1 NAME
-
-Filesys::POSIX::Mem::Bucket - Regular file I/O handle
-
-=head1 DESCRIPTION
-
-C<Filesys::POSIX::Mem::Bucket> provides an implementation of the interface in
-L<Filesys::POSIX::IO::Handle> that allows access to the regular file data of a
-file in a L<Filesys::POSIX::Mem> filesystem hierarchy.
-
-Internally, the bucket can store up to a specified maximum number of bytes until
-said data is flushed to a temporary file on disk, backed by L<File::Temp>.
-
-=cut
-
-our @ISA = ('Filesys::POSIX::IO::Handle');
+our @ISA = qw/Filesys::POSIX::IO::Handle/;
 
 my $DEFAULT_MAX = 16384;
 my $DEFAULT_DIR = '/tmp';
@@ -56,7 +31,9 @@ sub new {
 sub DESTROY {
     my ($self) = @_;
 
-    close $self->{'fh'} if $self->{'fh'};
+    if ( $self->{'fh'} ) {
+        close( $self->{'fh'} );
+    }
 
     if ( $self->{'file'} && -f $self->{'file'} ) {
         unlink $self->{'file'};
@@ -67,28 +44,30 @@ sub open {
     my ( $self, $flags ) = @_;
     $flags ||= 0;
 
-    throw &Errno::EBUSY if $self->{'fh'};
-
-    $self->{'pos'} = 0;
+    confess('Already opened') if $self->{'fh'};
 
     if ( $flags & $O_APPEND ) {
         $self->{'pos'} = $self->{'size'};
     }
-    elsif ( $flags & ( $O_CREAT | $O_TRUNC ) ) {
+    elsif ( $flags & $O_TRUNC ) {
+        $self->{'pos'}  = 0;
         $self->{'size'} = 0;
-        $self->{'inode'}->{'size'} = 0;
-
-        undef $self->{'buf'};
-        $self->{'buf'} = '';
     }
 
     if ( $self->{'file'} ) {
-        my $fcntl_flags = Filesys::POSIX::Bits::System::convertFlagsToSystem($flags);
-
-        sysopen( my $fh, $self->{'file'}, $fcntl_flags ) or Carp::confess("$!");
+        sysopen( my $fh, $self->{'file'}, $flags ) or confess("Unable to reopen bucket $self->{'file'}: $!");
 
         $self->{'fh'} = $fh;
     }
+    else {
+        if ( $flags & $O_TRUNC ) {
+            $self->{'size'} = 0;
+            undef $self->{'buf'};
+            $self->{'buf'} = '';
+        }
+    }
+
+    $self->{'inode'}->{'size'} = 0 if $flags & $O_TRUNC;
 
     return $self;
 }
@@ -96,12 +75,11 @@ sub open {
 sub _flush_to_disk {
     my ( $self, $len ) = @_;
 
-    throw &Errno::EALREADY if $self->{'file'};
+    confess('Already flushed to disk') if $self->{'file'};
 
-    my ( $fh, $file ) =
-      eval { File::Temp::mkstemp("$self->{'dir'}/.bucket-XXXXXX") };
+    my ( $fh, $file ) = eval { mkstemp("$self->{'dir'}/.bucket-XXXXXX") };
 
-    Carp::confess("mkstemp() failure: $@") if $@;
+    confess("mkstemp() failure: $@") if $@;
 
     my $offset = 0;
 
@@ -113,25 +91,19 @@ sub _flush_to_disk {
         $offset += $wrlen;
     }
 
-    @{$self}{qw(fh file)} = ( $fh, $file );
+    @{$self}{qw/fh file/} = ( $fh, $file );
 }
 
 sub write {
     my ( $self, $buf, $len ) = @_;
     my $ret = 0;
 
-    #
-    # If the current file position, plus the length of the intended write
-    # is to exceed the maximum memory bucket threshold, then dump the file
-    # to disk if it hasn't already happened.
-    #
-    if ( $self->{'pos'} + $len > $self->{'max'} ) {
-        $self->_flush_to_disk($len) unless $self->{'fh'};
+    unless ( $self->{'fh'} ) {
+        $self->_flush_to_disk($len) if $self->{'pos'} + $len > $self->{'max'};
     }
 
     if ( $self->{'fh'} ) {
-        Carp::confess("Unable to write to disk bucket")
-          unless fileno( $self->{'fh'} );
+        confess("Unable to write to disk bucket") unless fileno( $self->{'fh'} );
         $ret = syswrite( $self->{'fh'}, $buf );
     }
     else {
@@ -139,8 +111,7 @@ sub write {
             $self->{'buf'} .= "\x00" x $gap;
         }
 
-        substr( $self->{'buf'}, $self->{'pos'}, $len ) =
-          substr( $buf, 0, $len );
+        substr( $self->{'buf'}, $self->{'pos'}, $len ) = substr( $buf, 0, $len );
         $ret = $len;
     }
 
@@ -162,13 +133,11 @@ sub read {
     my $ret  = 0;
 
     if ( $self->{'fh'} ) {
-        Carp::confess("Unable to read bucket: $!")
-          unless fileno( $self->{'fh'} );
+        confess("Unable to read bucket: $!") unless fileno( $self->{'fh'} );
         $ret = sysread( $self->{'fh'}, $_[0], $len );
     }
     else {
-        my $pos =
-          $self->{'pos'} > $self->{'size'} ? $self->{'size'} : $self->{'pos'};
+        my $pos = $self->{'pos'} > $self->{'size'} ? $self->{'size'} : $self->{'pos'};
         my $maxlen = $self->{'size'} - $pos;
         $len = $maxlen if $len > $maxlen;
 
@@ -203,20 +172,14 @@ sub seek {
         $newpos = $self->{'size'} + $pos;
     }
     else {
-        throw &Errno::EINVAL;
+        confess('Invalid argument');
     }
 
     return $self->{'pos'} = $newpos;
 }
 
 sub tell {
-    my ($self) = @_;
-
-    if ( $self->{'fh'} ) {
-        return sysseek $self->{'fh'}, 0, 1;
-    }
-
-    return $self->{'pos'};
+    return shift->{'pos'};
 }
 
 sub close {
@@ -230,35 +193,4 @@ sub close {
     $self->{'pos'} = 0;
 }
 
-=head1 SEE ALSO
-
-=over
-
-=item L<Filesys::POSIX::IO::Handle>
-
-=back
-
-=cut
-
 1;
-
-__END__
-
-=head1 AUTHOR
-
-Written by Xan Tronix <xan@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item Rikus Goodell <rikus.goodell@cpanel.net>
-
-=item Brian Carlson <brian.carlson@cpanel.net>
-
-=back
-
-=head1 COPYRIGHT
-
-Copyright (c) 2014, cPanel, Inc.  Distributed under the terms of the Perl
-Artistic license.
